==> haskell-regex-tdfa-1.2.1-3-armv7h.pkg.tar.xz: usr/share/haskell/haskell-regex-tdfa/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: regex-tdfa
version: 1.2.1
id: regex-tdfa-1.2.1-2f2ff40a952b63109ef37be1ffea97d0
key: regex_G7b7xJat7lS8kB8q2srkoL
license: BSD3
copyright: Copyright (c) 2007, Christopher Kuklewicz
maintainer: TextRegexLazy@personal.mightyreason.com
stability: Seems to work, but not POSIX yet
homepage: http://hackage.haskell.org/package/regex-tdfa
package-url: http://code.haskell.org/regex-tdfa/
synopsis: Replaces/Enhances Text.Regex
description:
    A new all Haskell "tagged" DFA regex engine, inspired by libtre
category: Text
author: Christopher Kuklewicz
exposed: True
exposed-modules:
    Data.IntMap.CharMap2 Data.IntMap.EnumMap2 Data.IntSet.EnumSet2
    Text.Regex.TDFA Text.Regex.TDFA.ByteString
    Text.Regex.TDFA.ByteString.Lazy Text.Regex.TDFA.Common
    Text.Regex.TDFA.CorePattern Text.Regex.TDFA.IntArrTrieSet
    Text.Regex.TDFA.NewDFA.Engine Text.Regex.TDFA.NewDFA.Engine_FA
    Text.Regex.TDFA.NewDFA.Engine_NC
    Text.Regex.TDFA.NewDFA.Engine_NC_FA Text.Regex.TDFA.NewDFA.Tester
    Text.Regex.TDFA.NewDFA.Uncons Text.Regex.TDFA.NewDFA.MakeTest
    Text.Regex.TDFA.Pattern Text.Regex.TDFA.ReadRegex
    Text.Regex.TDFA.Sequence Text.Regex.TDFA.String
    Text.Regex.TDFA.TDFA Text.Regex.TDFA.TNFA
hidden-modules: Paths_regex_tdfa
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/regex-tdfa-1.2.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/regex-tdfa-1.2.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/regex-tdfa-1.2.1
hs-libraries: HSregex-tdfa-1.2.1-G7b7xJat7lS8kB8q2srkoL
depends:
    array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    ghc-prim-0.4.0.0-bf246eb9fdda7435f0c147a313ce59fb
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    parsec-3.1.9-e73195cf6af19ee9d1587f67fa792c42
    regex-base-0.93.2-42cdf19dc92d6af642a96da5984c8c2c
haddock-interfaces: /usr/share/doc/haskell-regex-tdfa/html/regex-tdfa.haddock
haddock-html: /usr/share/doc/haskell-regex-tdfa/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-regex-tdfa-1.2.1-4-armv7h.pkg.tar.xz: usr/share/haskell/haskell-regex-tdfa/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: regex-tdfa
version: 1.2.1
id: regex-tdfa-1.2.1-506e9a407febb132e40b4c629d403ead
key: regex_IJTo8JfTqsQ7Vol2eJqmYC
license: BSD3
copyright: Copyright (c) 2007, Christopher Kuklewicz
maintainer: TextRegexLazy@personal.mightyreason.com
stability: Seems to work, but not POSIX yet
homepage: http://hackage.haskell.org/package/regex-tdfa
package-url: http://code.haskell.org/regex-tdfa/
synopsis: Replaces/Enhances Text.Regex
description:
    A new all Haskell "tagged" DFA regex engine, inspired by libtre
category: Text
author: Christopher Kuklewicz
exposed: True
exposed-modules:
    Data.IntMap.CharMap2 Data.IntMap.EnumMap2 Data.IntSet.EnumSet2
    Text.Regex.TDFA Text.Regex.TDFA.ByteString
    Text.Regex.TDFA.ByteString.Lazy Text.Regex.TDFA.Common
    Text.Regex.TDFA.CorePattern Text.Regex.TDFA.IntArrTrieSet
    Text.Regex.TDFA.NewDFA.Engine Text.Regex.TDFA.NewDFA.Engine_FA
    Text.Regex.TDFA.NewDFA.Engine_NC
    Text.Regex.TDFA.NewDFA.Engine_NC_FA Text.Regex.TDFA.NewDFA.Tester
    Text.Regex.TDFA.NewDFA.Uncons Text.Regex.TDFA.NewDFA.MakeTest
    Text.Regex.TDFA.Pattern Text.Regex.TDFA.ReadRegex
    Text.Regex.TDFA.Sequence Text.Regex.TDFA.String
    Text.Regex.TDFA.TDFA Text.Regex.TDFA.TNFA
hidden-modules: Paths_regex_tdfa
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/regex-tdfa-1.2.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/regex-tdfa-1.2.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/regex-tdfa-1.2.1
hs-libraries: HSregex-tdfa-1.2.1-IJTo8JfTqsQ7Vol2eJqmYC
depends:
    array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    ghc-prim-0.4.0.0-bf246eb9fdda7435f0c147a313ce59fb
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    parsec-3.1.9-3365ddffd9ca11d2f0b377e002b54baf
    regex-base-0.93.2-42cdf19dc92d6af642a96da5984c8c2c
haddock-interfaces: /usr/share/doc/haskell-regex-tdfa/html/regex-tdfa.haddock
haddock-html: /usr/share/doc/haskell-regex-tdfa/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
